<?php
/**
 * @package Wapple_Architect
 * @subpackage WAPL Theme
 */

/**
 * Get WAPL header
 * @return string
 */
function get_wapl_header()
{
	$file = WP_PLUGIN_DIR.DIRECTORY_SEPARATOR.get_wapl_plugin_base().DIRECTORY_SEPARATOR.'theme'.DIRECTORY_SEPARATOR.'header.php';
	return include_once($file);
}

/**
 * Get WAPL footer
 * @return string
 */
function get_wapl_footer()
{
	$file = WP_PLUGIN_DIR.DIRECTORY_SEPARATOR.get_wapl_plugin_base().DIRECTORY_SEPARATOR.'theme'.DIRECTORY_SEPARATOR.'footer.php';
	return include_once($file);
}
/**
 * Get comments code
 * @return string 
 */
function get_wapl_comments()
{
	$file = WP_PLUGIN_DIR.DIRECTORY_SEPARATOR.get_wapl_plugin_base().DIRECTORY_SEPARATOR.'theme'.DIRECTORY_SEPARATOR.'comments.php';
	return include_once($file);
}

/**
 * Debug function
 * @param $debug mixed
 * @access public
 * @return void
 */
if(!function_exists('debug'))
{
	function debug($debug)
	{
		echo '<pre>'.print_r($debug,true).'</pre>';
	}
}

/**
 * Process WAPL into meaningful markup
 * @param $waplString string
 * @access public
 * @return void
 */
function process_wapl($waplString)
{
	if(ARCHITECT_DO_SOAP)
	{
		global $waplHeaders;
		global $waplSoapClient;
		
		$params = array('devKey' => get_option('architect_devkey'), 'wapl' => utf8_encode($waplString), 'deviceHeaders' => $waplHeaders);
		
		// Send markup to API and parse through simplexml
		$xml = simplexml_load_string($waplSoapClient->getMarkupFromWapl($params));
		
		foreach($xml->header->item as $val)
		{
			header($val);
		}
		echo trim($xml->markup);
	} else
	{
		header('Content-type: application/xml');
		echo $waplString;
	}
}

require_once('wapl_builder.php');
/**
 * WordPress WAPL parser
 * 
 * Extends the waplBuilder class to build perfect markup
 * @author Rich Gubby
 */
class WordPressWapl extends waplBuilder
{
	/**
	 * Format content into WAPL readable format
	 * @param string $content
	 * @param integer $imagescale
	 * @param integer $imagequality
	 * @param string $class
	 * @param integer $length
	 * @access public
	 * @return string
	 */
	function format_text($content, $imagescale = 95, $imagequality = 90, $class = 'entry', $length = null)
	{
		// Remove comments
		$content = str_replace(array('&#8211;', '&#8220;', '&#8221;'), array('--', '"', '"'), $content);
		$content = preg_replace('/<!--(.|\s)*?-->/', '', $content);
		
		require_once('simple_html_dom.php');
		$content = utf8_decode($content);
		
		$replacements = array();
		
		$html = str_get_html($content);
		// Remove script tags
		foreach($html->find('script') as $element)
		{
			$replacements[trim($element->outertext())] = '';
		}
		
		
		
		// Any special filters for other plugins
		$content = $this->__filters($content, $class);
		
		// Get rid of the "more" links - don't need these for mobile, they clutter things up
		if(!get_option('architect_home_showmore'))
		{
			foreach($html->find('a.more-link') as $element)
			{
				$replacements[trim($element->outertext())] = '';
			}
		}
		
		// Replace [caption] with <caption>
		$content = preg_replace('/(\[caption(.*?)\])(.*?)(\[\/caption\])/i', '<caption ${2}>${3}</caption>', $content);
		
		foreach($replacements as $key => $val)
		{
			$content = str_ireplace(trim($key), $val, $content);
		}
		
		// Use parent format text
		$content = parent::format_text($content, $imagescale, $imagequality, $class, $length);
		
		return $content;
	}
	
	/**
	 * Special filters written specifically for other plugins
	 * @param string $content
	 * @param string $class
	 * @access public
	 * @return string
	 */
	function __filters($content, $class)
	{
		// Path to extensions
		$path = '';
		if(defined('WP_PLUGIN_DIR'))
		{
			$path = WP_PLUGIN_DIR;
		} else if(defined('ABSPATH'))
		{
			$path = ABSPATH.'wp-content'.DIRECTORY_SEPARATOR.'plugins';
		}
		$path .= DIRECTORY_SEPARATOR.get_wapl_plugin_base().DIRECTORY_SEPARATOR.'extensions';
		
		if ($handle = opendir($path)) 
		{
			// Get all files in the extensions directory
			while (false !== ($file = readdir($handle))) 
			{
				if ($file != '.' && $file != '..' && $file != '.svn') 
				{
					// Include the file
					include_once($path.DIRECTORY_SEPARATOR.$file);
					
					// Get class name - should match the filename
					$className = substr($file,0,strpos($file,'.'));
					
					// Create a new class
					if(class_exists($className))
					{
						$filterClass = new $className;
					
						if(method_exists($filterClass, 'format'))
						{
							// Return formatted text
							$content = $filterClass->format($content, $class);
						}
					} 
				}
			}
			closedir($handle);
		}
		return $content;
	}
}

/**
 * Load a WAPL element
 * @param $element string
 * @access public
 * @return void
 */
function get_wapl_element($element)
{
	return require('elements/'.$element.'.php');
}

function get_wapl_response_string($type, $count, $title = '')
{
	$responseFormat = array(
		1 => array(
			0 => '%d responses',
			1 => '%d response',
			2 => '%d responses'
		),
		2 => array(
			0 => '%d responses to %s',
			1 => '%d response to %s',
			2 => '%d responses to %s'
		),
		3 => array(
			0 => '%d comments',
			1 => '%d comment',
			2 => '%d comments'
		),
		4 => array(
			0 => '%d comments to %s',
			1 => '%d comment to %s',
			2 => '%d comments to %s'
		)
	);
	if($count == 0 || $count == 1)
	{
		return sprintf($responseFormat[$type][$count], $count, $title);
	} else
	{
		return sprintf($responseFormat[$type][2], $count, $title);
	}
}

if(!function_exists('architect_curPageURL'))
{
	function architect_curPageURL() 
	{
		$pageURL = 'http';
		if (isset($_SERVER["HTTPS"]) AND $_SERVER["HTTPS"] == "on") {$pageURL .= "s";}
		$pageURL .= "://";
		if ($_SERVER["SERVER_PORT"] != "80") {
			$pageURL .= $_SERVER["SERVER_NAME"].":".$_SERVER["SERVER_PORT"].$_SERVER["REQUEST_URI"];
		} else 
		{
			$pageURL .= $_SERVER["SERVER_NAME"].$_SERVER["REQUEST_URI"];
		}
		return $pageURL;
	}
}

if(!function_exists('architect_buildUrl'))
{
	function architect_buildUrl($url, $options = array())
	{
		$parsedUrl = parse_url($url);
		
		$return = $parsedUrl['scheme'].'://'.$parsedUrl['host'].$parsedUrl['path'];
		if(isset($parsedUrl['query']))
		{
			$parsedUrl['query'] .= '&mobile=0';
			$i=0;
			foreach(explode('&', $parsedUrl['query']) as $key => $val)
			{
				if($i == 0)
				{
					$return .= '?';
				} else
				{
					$return .= '&amp;';
				}
				$return .= $val;
				$i++;
			}
		} else
		{
			$return .= '?mobile=0';
		}
		return $return;
	}
}

if(!function_exists('get_author_posts_url'))
{
	function get_author_posts_url($author_id, $author_nicename = '') {
		global $wp_rewrite;
		$auth_ID = (int) $author_id;
		$link = $wp_rewrite->get_author_permastruct();
	
		if ( empty($link) ) {
			$file = get_option('home') . '/';
			$link = $file . '?author=' . $auth_ID;
		} else {
			if ( '' == $author_nicename ) {
				$user = get_userdata($author_id);
				if ( !empty($user->user_nicename) )
					$author_nicename = $user->user_nicename;
			}
			$link = str_replace('%author%', $author_nicename, $link);
			$link = get_option('home') . trailingslashit($link);
		}
	
		$link = apply_filters('author_link', $link, $author_id, $author_nicename);
	
		return $link;
	}
}
?>